"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importDefault(require("express"));
const cors_1 = __importDefault(require("cors"));
const Ogc3D_1 = require("./src/Ogc3D");
const ErrorHandler_1 = require("./src/ErrorHandler");
const app = express_1.default();
app.use(cors_1.default());
const PORT = 3001;
// Routes
app.get("/", (req, res) => {
    console.debug("Received request for Landing Page");
    res.send(Ogc3D_1.loadLandingPage());
});
app.get("/conformance", (req, res) => {
    console.debug("Received request for conformance");
    res.send(Ogc3D_1.loadConformance());
});
app.get("/collections", (req, res) => {
    console.debug("Received request for collections");
    res.send(Ogc3D_1.loadCollections());
});
app.get("/collections/*", (req, res) => {
    console.debug("Received request for subcollections");
    const subCollections = req.params[0].split("/").filter(val => !!val);
    res.send(Ogc3D_1.loadSubCollections(subCollections, req.query.format));
});
// Error Handling
// noinspection JSUnusedLocalSymbols
app.use(function (err, req, res, next) {
    const errorResponse = ErrorHandler_1.mapError(err);
    res.status(errorResponse.status).send(errorResponse);
});
app.use("/public", express_1.default.static("public"));
// Start Application
app.listen(PORT, () => {
    console.log(`⚡️[server]: Server is running at http://localhost:${PORT}`);
});
//# sourceMappingURL=index.js.map