"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormatNotFoundException = exports.CollectionNotFoundException = exports.loadSubCollections = exports.loadCollections = exports.loadConformance = exports.loadLandingPage = void 0;
const LandingPage_json_1 = __importDefault(require("../containerAPI/LandingPage.json"));
const Conformance_json_1 = __importDefault(require("../containerAPI/Conformance.json"));
const Collections_json_1 = __importDefault(require("../containerAPI/Collections.json"));
const ogc3dcontainerentitiesmodel_1 = require("ogc3dcontainerentitiesmodel");
const ogc3dcontainerentitiesmodel_2 = require("ogc3dcontainerentitiesmodel");
const loadLandingPage = () => {
    return ogc3dcontainerentitiesmodel_1.LandingPage.fromJson(LandingPage_json_1.default);
};
exports.loadLandingPage = loadLandingPage;
const loadConformance = () => {
    return ogc3dcontainerentitiesmodel_2.Conformance.fromJson(Conformance_json_1.default);
};
exports.loadConformance = loadConformance;
const loadCollections = () => {
    return ogc3dcontainerentitiesmodel_1.Collections.fromJson(Collections_json_1.default);
};
exports.loadCollections = loadCollections;
const loadSubCollections = (collectionIds, format) => {
    var _a, _b;
    let collection = ogc3dcontainerentitiesmodel_1.Collections.fromJson(Collections_json_1.default);
    collectionIds.forEach(id => {
        let subCollections;
        if (collection instanceof ogc3dcontainerentitiesmodel_1.Collections) {
            subCollections = collection.collections;
        }
        else if (collection instanceof ogc3dcontainerentitiesmodel_1._3DContainer) {
            subCollections = collection.children;
        }
        collection = subCollections === null || subCollections === void 0 ? void 0 : subCollections.find(c => c.id == id);
        if (!collection) {
            throw new CollectionNotFoundException(`Collection with id '${id}' is not found!`);
        }
    });
    if (format) {
        let container = collection;
        const link = (_a = container === null || container === void 0 ? void 0 : container.content) === null || _a === void 0 ? void 0 : _a.find(link => link.type === format);
        if (!link) {
            const availableFormats = (_b = container === null || container === void 0 ? void 0 : container.content) === null || _b === void 0 ? void 0 : _b.map(link => link.type);
            let exceptionMessage = `Format '${format}' is not found!`;
            if (availableFormats && availableFormats.length) {
                const distinctFormats = [...new Set(availableFormats)].join(", ");
                exceptionMessage += `. Available formats: [${distinctFormats}]`;
            }
            throw new FormatNotFoundException(exceptionMessage);
        }
        return link;
    }
    return collection;
};
exports.loadSubCollections = loadSubCollections;
class CollectionNotFoundException extends Error {
    constructor() {
        super(...arguments);
        this.name = "Collection_Not_Found";
    }
}
exports.CollectionNotFoundException = CollectionNotFoundException;
class FormatNotFoundException extends Error {
    constructor() {
        super(...arguments);
        this.name = "Format_Not_Found";
    }
}
exports.FormatNotFoundException = FormatNotFoundException;
//# sourceMappingURL=Ogc3D.js.map