import {default as LandingPageJson} from "../containerAPI/LandingPage.json";
import {default as ConformanceJson} from "../containerAPI/Conformance.json";
import {default as CollectionsJson} from "../containerAPI/Collections.json";
import {_3DContainer, Collections, LandingPage} from "ogc3dcontainerentitiesmodel";
import {Conformance} from "ogc3dcontainerentitiesmodel";

export const loadLandingPage = () => {
    return LandingPage.fromJson(LandingPageJson);
};

export const loadConformance = () => {
    return Conformance.fromJson(ConformanceJson);
};

export const loadCollections = () => {
    return Collections.fromJson(CollectionsJson);
};

export const loadSubCollections = (collectionIds: string[], format: string | undefined) => {
    let collection: Collections | _3DContainer | undefined = Collections.fromJson(CollectionsJson);

    collectionIds.forEach(id => {
        let subCollections;
        if (collection instanceof Collections) {
            subCollections = collection.collections;
        } else if (collection instanceof _3DContainer) {
            subCollections = collection.children;
        }
        collection = subCollections?.find(c => c.id == id);
        if (!collection) {
            throw new CollectionNotFoundException(`Collection with id '${id}' is not found!`);
        }
    });
    if (format) {
        let container  = collection as _3DContainer;
        const link = container?.content?.find(link => link.type === format!);
        if (!link) {
            const availableFormats = container?.content?.map(link => link.type);
            let exceptionMessage = `Format '${format}' is not found!`;
            if (availableFormats && availableFormats.length) {
                const distinctFormats = [...new Set(availableFormats)].join(", ");
                exceptionMessage += `. Available formats: [${distinctFormats}]`;
            }
            throw new FormatNotFoundException(exceptionMessage);
        }
        return link;
    }
    return collection;
};

export class CollectionNotFoundException extends Error {
    name = "Collection_Not_Found";
}

export class FormatNotFoundException extends Error {
    name = "Format_Not_Found";
}
